@@ -1,14 +1,14 @@
 """
 Type annotations for acm-pca service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/type_defs/)
 
 Usage::
 
     ```python
-    from mypy_boto3_acm_pca.type_defs import ASN1SubjectTypeDef
+    from mypy_boto3_acm_pca.type_defs import CustomAttributeTypeDef
 
-    data: ASN1SubjectTypeDef = {...}
+    data: CustomAttributeTypeDef = {...}
     ```
 """
 import sys
@@ -24,6 +24,7 @@ from .literals import (
     AuditReportStatusType,
     CertificateAuthorityStatusType,
     CertificateAuthorityTypeType,
+    CertificateAuthorityUsageModeType,
     ExtendedKeyUsageTypeType,
     FailureReasonType,
     KeyAlgorithmType,
@@ -35,105 +36,93 @@ from .literals import (
     ValidityPeriodTypeType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
 
 
 __all__ = (
-    "ASN1SubjectTypeDef",
-    "AccessDescriptionTypeDef",
+    "CustomAttributeTypeDef",
     "AccessMethodTypeDef",
-    "ApiPassthroughTypeDef",
-    "CertificateAuthorityConfigurationTypeDef",
-    "CertificateAuthorityTypeDef",
     "CreateCertificateAuthorityAuditReportRequestRequestTypeDef",
-    "CreateCertificateAuthorityAuditReportResponseTypeDef",
-    "CreateCertificateAuthorityRequestRequestTypeDef",
-    "CreateCertificateAuthorityResponseTypeDef",
+    "ResponseMetadataTypeDef",
+    "TagTypeDef",
     "CreatePermissionRequestRequestTypeDef",
     "CrlConfigurationTypeDef",
-    "CsrExtensionsTypeDef",
+    "KeyUsageTypeDef",
+    "CustomExtensionTypeDef",
     "DeleteCertificateAuthorityRequestRequestTypeDef",
     "DeletePermissionRequestRequestTypeDef",
     "DeletePolicyRequestRequestTypeDef",
+    "WaiterConfigTypeDef",
     "DescribeCertificateAuthorityAuditReportRequestRequestTypeDef",
-    "DescribeCertificateAuthorityAuditReportResponseTypeDef",
     "DescribeCertificateAuthorityRequestRequestTypeDef",
-    "DescribeCertificateAuthorityResponseTypeDef",
     "EdiPartyNameTypeDef",
     "ExtendedKeyUsageTypeDef",
-    "ExtensionsTypeDef",
-    "GeneralNameTypeDef",
-    "GetCertificateAuthorityCertificateRequestRequestTypeDef",
-    "GetCertificateAuthorityCertificateResponseTypeDef",
-    "GetCertificateAuthorityCsrRequestRequestTypeDef",
-    "GetCertificateAuthorityCsrResponseTypeDef",
-    "GetCertificateRequestRequestTypeDef",
-    "GetCertificateResponseTypeDef",
-    "GetPolicyRequestRequestTypeDef",
-    "GetPolicyResponseTypeDef",
-    "ImportCertificateAuthorityCertificateRequestRequestTypeDef",
-    "IssueCertificateRequestRequestTypeDef",
-    "IssueCertificateResponseTypeDef",
-    "KeyUsageTypeDef",
-    "ListCertificateAuthoritiesRequestRequestTypeDef",
-    "ListCertificateAuthoritiesResponseTypeDef",
-    "ListPermissionsRequestRequestTypeDef",
-    "ListPermissionsResponseTypeDef",
-    "ListTagsRequestRequestTypeDef",
-    "ListTagsResponseTypeDef",
-    "OcspConfigurationTypeDef",
     "OtherNameTypeDef",
-    "PaginatorConfigTypeDef",
-    "PermissionTypeDef",
-    "PolicyInformationTypeDef",
-    "PolicyQualifierInfoTypeDef",
-    "PutPolicyRequestRequestTypeDef",
-    "QualifierTypeDef",
-    "ResponseMetadataTypeDef",
-    "RestoreCertificateAuthorityRequestRequestTypeDef",
-    "RevocationConfigurationTypeDef",
-    "RevokeCertificateRequestRequestTypeDef",
-    "TagCertificateAuthorityRequestRequestTypeDef",
-    "TagTypeDef",
-    "UntagCertificateAuthorityRequestRequestTypeDef",
-    "UpdateCertificateAuthorityRequestRequestTypeDef",
+    "GetCertificateAuthorityCertificateRequestRequestTypeDef",
+    "GetCertificateAuthorityCsrRequestRequestTypeDef",
+    "GetCertificateRequestRequestTypeDef",
+    "GetPolicyRequestRequestTypeDef",
+    "ImportCertificateAuthorityCertificateRequestRequestTypeDef",
     "ValidityTypeDef",
-    "WaiterConfigTypeDef",
-)
-
-ASN1SubjectTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    "ListCertificateAuthoritiesRequestRequestTypeDef",
+    "ListPermissionsRequestRequestTypeDef",
+    "PermissionTypeDef",
+    "ListTagsRequestRequestTypeDef",
+    "OcspConfigurationTypeDef",
+    "QualifierTypeDef",
+    "PutPolicyRequestRequestTypeDef",
+    "RestoreCertificateAuthorityRequestRequestTypeDef",
+    "RevokeCertificateRequestRequestTypeDef",
     "ASN1SubjectTypeDef",
-    {
-        "Country": str,
-        "Organization": str,
-        "OrganizationalUnit": str,
-        "DistinguishedNameQualifier": str,
-        "State": str,
-        "CommonName": str,
-        "SerialNumber": str,
-        "Locality": str,
-        "Title": str,
-        "Surname": str,
-        "GivenName": str,
-        "Initials": str,
-        "Pseudonym": str,
-        "GenerationQualifier": str,
-    },
-    total=False,
+    "CreateCertificateAuthorityAuditReportResponseTypeDef",
+    "CreateCertificateAuthorityResponseTypeDef",
+    "DescribeCertificateAuthorityAuditReportResponseTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "GetCertificateAuthorityCertificateResponseTypeDef",
+    "GetCertificateAuthorityCsrResponseTypeDef",
+    "GetCertificateResponseTypeDef",
+    "GetPolicyResponseTypeDef",
+    "IssueCertificateResponseTypeDef",
+    "ListTagsResponseTypeDef",
+    "TagCertificateAuthorityRequestRequestTypeDef",
+    "UntagCertificateAuthorityRequestRequestTypeDef",
+    "DescribeCertificateAuthorityAuditReportRequestAuditReportCreatedWaitTypeDef",
+    "GetCertificateAuthorityCsrRequestCertificateAuthorityCSRCreatedWaitTypeDef",
+    "GetCertificateRequestCertificateIssuedWaitTypeDef",
+    "ListCertificateAuthoritiesRequestListCertificateAuthoritiesPaginateTypeDef",
+    "ListPermissionsRequestListPermissionsPaginateTypeDef",
+    "ListTagsRequestListTagsPaginateTypeDef",
+    "ListPermissionsResponseTypeDef",
+    "RevocationConfigurationTypeDef",
+    "PolicyQualifierInfoTypeDef",
+    "GeneralNameTypeDef",
+    "UpdateCertificateAuthorityRequestRequestTypeDef",
+    "PolicyInformationTypeDef",
+    "AccessDescriptionTypeDef",
+    "ExtensionsTypeDef",
+    "CsrExtensionsTypeDef",
+    "ApiPassthroughTypeDef",
+    "CertificateAuthorityConfigurationTypeDef",
+    "IssueCertificateRequestRequestTypeDef",
+    "CertificateAuthorityTypeDef",
+    "CreateCertificateAuthorityRequestRequestTypeDef",
+    "DescribeCertificateAuthorityResponseTypeDef",
+    "ListCertificateAuthoritiesResponseTypeDef",
 )
 
-AccessDescriptionTypeDef = TypedDict(
-    "AccessDescriptionTypeDef",
+CustomAttributeTypeDef = TypedDict(
+    "CustomAttributeTypeDef",
     {
-        "AccessMethod": "AccessMethodTypeDef",
-        "AccessLocation": "GeneralNameTypeDef",
+        "ObjectIdentifier": str,
+        "Value": str,
     },
 )
 
@@ -146,60 +135,6 @@ AccessMethodTypeDef = TypedDict(
     total=False,
 )
 
-ApiPassthroughTypeDef = TypedDict(
-    "ApiPassthroughTypeDef",
-    {
-        "Extensions": "ExtensionsTypeDef",
-        "Subject": "ASN1SubjectTypeDef",
-    },
-    total=False,
-)
-
-_RequiredCertificateAuthorityConfigurationTypeDef = TypedDict(
-    "_RequiredCertificateAuthorityConfigurationTypeDef",
-    {
-        "KeyAlgorithm": KeyAlgorithmType,
-        "SigningAlgorithm": SigningAlgorithmType,
-        "Subject": "ASN1SubjectTypeDef",
-    },
-)
-_OptionalCertificateAuthorityConfigurationTypeDef = TypedDict(
-    "_OptionalCertificateAuthorityConfigurationTypeDef",
-    {
-        "CsrExtensions": "CsrExtensionsTypeDef",
-    },
-    total=False,
-)
-
-
-class CertificateAuthorityConfigurationTypeDef(
-    _RequiredCertificateAuthorityConfigurationTypeDef,
-    _OptionalCertificateAuthorityConfigurationTypeDef,
-):
-    pass
-
-
-CertificateAuthorityTypeDef = TypedDict(
-    "CertificateAuthorityTypeDef",
-    {
-        "Arn": str,
-        "OwnerAccount": str,
-        "CreatedAt": datetime,
-        "LastStateChangeAt": datetime,
-        "Type": CertificateAuthorityTypeType,
-        "Serial": str,
-        "Status": CertificateAuthorityStatusType,
-        "NotBefore": datetime,
-        "NotAfter": datetime,
-        "FailureReason": FailureReasonType,
-        "CertificateAuthorityConfiguration": "CertificateAuthorityConfigurationTypeDef",
-        "RevocationConfiguration": "RevocationConfigurationTypeDef",
-        "RestorableUntil": datetime,
-        "KeyStorageSecurityStandard": KeyStorageSecurityStandardType,
-    },
-    total=False,
-)
-
 CreateCertificateAuthorityAuditReportRequestRequestTypeDef = TypedDict(
     "CreateCertificateAuthorityAuditReportRequestRequestTypeDef",
     {
@@ -209,49 +144,36 @@ CreateCertificateAuthorityAuditReportRequestRequestTypeDef = TypedDict(
     },
 )
 
-CreateCertificateAuthorityAuditReportResponseTypeDef = TypedDict(
-    "CreateCertificateAuthorityAuditReportResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "AuditReportId": str,
-        "S3Key": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
-_RequiredCreateCertificateAuthorityRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateCertificateAuthorityRequestRequestTypeDef",
+_RequiredTagTypeDef = TypedDict(
+    "_RequiredTagTypeDef",
     {
-        "CertificateAuthorityConfiguration": "CertificateAuthorityConfigurationTypeDef",
-        "CertificateAuthorityType": CertificateAuthorityTypeType,
+        "Key": str,
     },
 )
-_OptionalCreateCertificateAuthorityRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateCertificateAuthorityRequestRequestTypeDef",
+_OptionalTagTypeDef = TypedDict(
+    "_OptionalTagTypeDef",
     {
-        "RevocationConfiguration": "RevocationConfigurationTypeDef",
-        "IdempotencyToken": str,
-        "KeyStorageSecurityStandard": KeyStorageSecurityStandardType,
-        "Tags": Sequence["TagTypeDef"],
+        "Value": str,
     },
     total=False,
 )
 
 
-class CreateCertificateAuthorityRequestRequestTypeDef(
-    _RequiredCreateCertificateAuthorityRequestRequestTypeDef,
-    _OptionalCreateCertificateAuthorityRequestRequestTypeDef,
-):
+class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
     pass
 
 
-CreateCertificateAuthorityResponseTypeDef = TypedDict(
-    "CreateCertificateAuthorityResponseTypeDef",
-    {
-        "CertificateAuthorityArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredCreatePermissionRequestRequestTypeDef = TypedDict(
     "_RequiredCreatePermissionRequestRequestTypeDef",
     {
@@ -297,15 +219,42 @@ class CrlConfigurationTypeDef(_RequiredCrlConfigurationTypeDef, _OptionalCrlConf
     pass
 
 
-CsrExtensionsTypeDef = TypedDict(
-    "CsrExtensionsTypeDef",
+KeyUsageTypeDef = TypedDict(
+    "KeyUsageTypeDef",
     {
-        "KeyUsage": "KeyUsageTypeDef",
-        "SubjectInformationAccess": Sequence["AccessDescriptionTypeDef"],
+        "DigitalSignature": bool,
+        "NonRepudiation": bool,
+        "KeyEncipherment": bool,
+        "DataEncipherment": bool,
+        "KeyAgreement": bool,
+        "KeyCertSign": bool,
+        "CRLSign": bool,
+        "EncipherOnly": bool,
+        "DecipherOnly": bool,
     },
     total=False,
 )
 
+_RequiredCustomExtensionTypeDef = TypedDict(
+    "_RequiredCustomExtensionTypeDef",
+    {
+        "ObjectIdentifier": str,
+        "Value": str,
+    },
+)
+_OptionalCustomExtensionTypeDef = TypedDict(
+    "_OptionalCustomExtensionTypeDef",
+    {
+        "Critical": bool,
+    },
+    total=False,
+)
+
+
+class CustomExtensionTypeDef(_RequiredCustomExtensionTypeDef, _OptionalCustomExtensionTypeDef):
+    pass
+
+
 _RequiredDeleteCertificateAuthorityRequestRequestTypeDef = TypedDict(
     "_RequiredDeleteCertificateAuthorityRequestRequestTypeDef",
     {
@@ -357,6 +306,15 @@ DeletePolicyRequestRequestTypeDef = TypedDict(
     },
 )
 
+WaiterConfigTypeDef = TypedDict(
+    "WaiterConfigTypeDef",
+    {
+        "Delay": int,
+        "MaxAttempts": int,
+    },
+    total=False,
+)
+
 DescribeCertificateAuthorityAuditReportRequestRequestTypeDef = TypedDict(
     "DescribeCertificateAuthorityAuditReportRequestRequestTypeDef",
     {
@@ -365,17 +323,6 @@ DescribeCertificateAuthorityAuditReportRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeCertificateAuthorityAuditReportResponseTypeDef = TypedDict(
-    "DescribeCertificateAuthorityAuditReportResponseTypeDef",
-    {
-        "AuditReportStatus": AuditReportStatusType,
-        "S3BucketName": str,
-        "S3Key": str,
-        "CreatedAt": datetime,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeCertificateAuthorityRequestRequestTypeDef = TypedDict(
     "DescribeCertificateAuthorityRequestRequestTypeDef",
     {
@@ -383,14 +330,6 @@ DescribeCertificateAuthorityRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeCertificateAuthorityResponseTypeDef = TypedDict(
-    "DescribeCertificateAuthorityResponseTypeDef",
-    {
-        "CertificateAuthority": "CertificateAuthorityTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredEdiPartyNameTypeDef = TypedDict(
     "_RequiredEdiPartyNameTypeDef",
     {
@@ -419,30 +358,12 @@ ExtendedKeyUsageTypeDef = TypedDict(
     total=False,
 )
 
-ExtensionsTypeDef = TypedDict(
-    "ExtensionsTypeDef",
+OtherNameTypeDef = TypedDict(
+    "OtherNameTypeDef",
     {
-        "CertificatePolicies": Sequence["PolicyInformationTypeDef"],
-        "ExtendedKeyUsage": Sequence["ExtendedKeyUsageTypeDef"],
-        "KeyUsage": "KeyUsageTypeDef",
-        "SubjectAlternativeNames": Sequence["GeneralNameTypeDef"],
+        "TypeId": str,
+        "Value": str,
     },
-    total=False,
-)
-
-GeneralNameTypeDef = TypedDict(
-    "GeneralNameTypeDef",
-    {
-        "OtherName": "OtherNameTypeDef",
-        "Rfc822Name": str,
-        "DnsName": str,
-        "DirectoryName": "ASN1SubjectTypeDef",
-        "EdiPartyName": "EdiPartyNameTypeDef",
-        "UniformResourceIdentifier": str,
-        "IpAddress": str,
-        "RegisteredId": str,
-    },
-    total=False,
 )
 
 GetCertificateAuthorityCertificateRequestRequestTypeDef = TypedDict(
@@ -452,15 +373,6 @@ GetCertificateAuthorityCertificateRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetCertificateAuthorityCertificateResponseTypeDef = TypedDict(
-    "GetCertificateAuthorityCertificateResponseTypeDef",
-    {
-        "Certificate": str,
-        "CertificateChain": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetCertificateAuthorityCsrRequestRequestTypeDef = TypedDict(
     "GetCertificateAuthorityCsrRequestRequestTypeDef",
     {
@@ -468,14 +380,6 @@ GetCertificateAuthorityCsrRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetCertificateAuthorityCsrResponseTypeDef = TypedDict(
-    "GetCertificateAuthorityCsrResponseTypeDef",
-    {
-        "Csr": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetCertificateRequestRequestTypeDef = TypedDict(
     "GetCertificateRequestRequestTypeDef",
     {
@@ -484,15 +388,6 @@ GetCertificateRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetCertificateResponseTypeDef = TypedDict(
-    "GetCertificateResponseTypeDef",
-    {
-        "Certificate": str,
-        "CertificateChain": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetPolicyRequestRequestTypeDef = TypedDict(
     "GetPolicyRequestRequestTypeDef",
     {
@@ -500,25 +395,17 @@ GetPolicyRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetPolicyResponseTypeDef = TypedDict(
-    "GetPolicyResponseTypeDef",
-    {
-        "Policy": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredImportCertificateAuthorityCertificateRequestRequestTypeDef = TypedDict(
     "_RequiredImportCertificateAuthorityCertificateRequestRequestTypeDef",
     {
         "CertificateAuthorityArn": str,
-        "Certificate": Union[bytes, IO[bytes], StreamingBody],
+        "Certificate": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 _OptionalImportCertificateAuthorityCertificateRequestRequestTypeDef = TypedDict(
     "_OptionalImportCertificateAuthorityCertificateRequestRequestTypeDef",
     {
-        "CertificateChain": Union[bytes, IO[bytes], StreamingBody],
+        "CertificateChain": Union[str, bytes, IO[Any], StreamingBody],
     },
     total=False,
 )
@@ -531,53 +418,20 @@ class ImportCertificateAuthorityCertificateRequestRequestTypeDef(
     pass
 
 
-_RequiredIssueCertificateRequestRequestTypeDef = TypedDict(
-    "_RequiredIssueCertificateRequestRequestTypeDef",
+ValidityTypeDef = TypedDict(
+    "ValidityTypeDef",
     {
-        "CertificateAuthorityArn": str,
-        "Csr": Union[bytes, IO[bytes], StreamingBody],
-        "SigningAlgorithm": SigningAlgorithmType,
-        "Validity": "ValidityTypeDef",
-    },
-)
-_OptionalIssueCertificateRequestRequestTypeDef = TypedDict(
-    "_OptionalIssueCertificateRequestRequestTypeDef",
-    {
-        "ApiPassthrough": "ApiPassthroughTypeDef",
-        "TemplateArn": str,
-        "ValidityNotBefore": "ValidityTypeDef",
-        "IdempotencyToken": str,
-    },
-    total=False,
-)
-
-
-class IssueCertificateRequestRequestTypeDef(
-    _RequiredIssueCertificateRequestRequestTypeDef, _OptionalIssueCertificateRequestRequestTypeDef
-):
-    pass
-
-
-IssueCertificateResponseTypeDef = TypedDict(
-    "IssueCertificateResponseTypeDef",
-    {
-        "CertificateArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Value": int,
+        "Type": ValidityPeriodTypeType,
     },
 )
 
-KeyUsageTypeDef = TypedDict(
-    "KeyUsageTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "DigitalSignature": bool,
-        "NonRepudiation": bool,
-        "KeyEncipherment": bool,
-        "DataEncipherment": bool,
-        "KeyAgreement": bool,
-        "KeyCertSign": bool,
-        "CRLSign": bool,
-        "EncipherOnly": bool,
-        "DecipherOnly": bool,
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
@@ -592,15 +446,6 @@ ListCertificateAuthoritiesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListCertificateAuthoritiesResponseTypeDef = TypedDict(
-    "ListCertificateAuthoritiesResponseTypeDef",
-    {
-        "CertificateAuthorities": List["CertificateAuthorityTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListPermissionsRequestRequestTypeDef = TypedDict(
     "_RequiredListPermissionsRequestRequestTypeDef",
     {
@@ -623,13 +468,17 @@ class ListPermissionsRequestRequestTypeDef(
     pass
 
 
-ListPermissionsResponseTypeDef = TypedDict(
-    "ListPermissionsResponseTypeDef",
+PermissionTypeDef = TypedDict(
+    "PermissionTypeDef",
     {
-        "Permissions": List["PermissionTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "CertificateAuthorityArn": str,
+        "CreatedAt": datetime,
+        "Principal": str,
+        "SourceAccount": str,
+        "Actions": List[ActionTypeType],
+        "Policy": str,
     },
+    total=False,
 )
 
 _RequiredListTagsRequestRequestTypeDef = TypedDict(
@@ -654,15 +503,6 @@ class ListTagsRequestRequestTypeDef(
     pass
 
 
-ListTagsResponseTypeDef = TypedDict(
-    "ListTagsResponseTypeDef",
-    {
-        "Tags": List["TagTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredOcspConfigurationTypeDef = TypedDict(
     "_RequiredOcspConfigurationTypeDef",
     {
@@ -684,63 +524,10 @@ class OcspConfigurationTypeDef(
     pass
 
 
-OtherNameTypeDef = TypedDict(
-    "OtherNameTypeDef",
+QualifierTypeDef = TypedDict(
+    "QualifierTypeDef",
     {
-        "TypeId": str,
-        "Value": str,
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-PermissionTypeDef = TypedDict(
-    "PermissionTypeDef",
-    {
-        "CertificateAuthorityArn": str,
-        "CreatedAt": datetime,
-        "Principal": str,
-        "SourceAccount": str,
-        "Actions": List[ActionTypeType],
-        "Policy": str,
-    },
-    total=False,
-)
-
-_RequiredPolicyInformationTypeDef = TypedDict(
-    "_RequiredPolicyInformationTypeDef",
-    {
-        "CertPolicyId": str,
-    },
-)
-_OptionalPolicyInformationTypeDef = TypedDict(
-    "_OptionalPolicyInformationTypeDef",
-    {
-        "PolicyQualifiers": Sequence["PolicyQualifierInfoTypeDef"],
-    },
-    total=False,
-)
-
-
-class PolicyInformationTypeDef(
-    _RequiredPolicyInformationTypeDef, _OptionalPolicyInformationTypeDef
-):
-    pass
-
-
-PolicyQualifierInfoTypeDef = TypedDict(
-    "PolicyQualifierInfoTypeDef",
-    {
-        "PolicyQualifierId": Literal["CPS"],
-        "Qualifier": "QualifierTypeDef",
+        "CpsUri": str,
     },
 )
 
@@ -752,24 +539,6 @@ PutPolicyRequestRequestTypeDef = TypedDict(
     },
 )
 
-QualifierTypeDef = TypedDict(
-    "QualifierTypeDef",
-    {
-        "CpsUri": str,
-    },
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
-        "RetryAttempts": int,
-    },
-)
-
 RestoreCertificateAuthorityRequestRequestTypeDef = TypedDict(
     "RestoreCertificateAuthorityRequestRequestTypeDef",
     {
@@ -777,15 +546,6 @@ RestoreCertificateAuthorityRequestRequestTypeDef = TypedDict(
     },
 )
 
-RevocationConfigurationTypeDef = TypedDict(
-    "RevocationConfigurationTypeDef",
-    {
-        "CrlConfiguration": "CrlConfigurationTypeDef",
-        "OcspConfiguration": "OcspConfigurationTypeDef",
-    },
-    total=False,
-)
-
 RevokeCertificateRequestRequestTypeDef = TypedDict(
     "RevokeCertificateRequestRequestTypeDef",
     {
@@ -795,41 +555,291 @@ RevokeCertificateRequestRequestTypeDef = TypedDict(
     },
 )
 
-TagCertificateAuthorityRequestRequestTypeDef = TypedDict(
-    "TagCertificateAuthorityRequestRequestTypeDef",
+ASN1SubjectTypeDef = TypedDict(
+    "ASN1SubjectTypeDef",
     {
-        "CertificateAuthorityArn": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-)
-
-_RequiredTagTypeDef = TypedDict(
-    "_RequiredTagTypeDef",
-    {
-        "Key": str,
-    },
-)
-_OptionalTagTypeDef = TypedDict(
-    "_OptionalTagTypeDef",
-    {
-        "Value": str,
+        "Country": str,
+        "Organization": str,
+        "OrganizationalUnit": str,
+        "DistinguishedNameQualifier": str,
+        "State": str,
+        "CommonName": str,
+        "SerialNumber": str,
+        "Locality": str,
+        "Title": str,
+        "Surname": str,
+        "GivenName": str,
+        "Initials": str,
+        "Pseudonym": str,
+        "GenerationQualifier": str,
+        "CustomAttributes": Sequence[CustomAttributeTypeDef],
     },
     total=False,
 )
 
+CreateCertificateAuthorityAuditReportResponseTypeDef = TypedDict(
+    "CreateCertificateAuthorityAuditReportResponseTypeDef",
+    {
+        "AuditReportId": str,
+        "S3Key": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
 
-class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
-    pass
+CreateCertificateAuthorityResponseTypeDef = TypedDict(
+    "CreateCertificateAuthorityResponseTypeDef",
+    {
+        "CertificateAuthorityArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
 
+DescribeCertificateAuthorityAuditReportResponseTypeDef = TypedDict(
+    "DescribeCertificateAuthorityAuditReportResponseTypeDef",
+    {
+        "AuditReportStatus": AuditReportStatusType,
+        "S3BucketName": str,
+        "S3Key": str,
+        "CreatedAt": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetCertificateAuthorityCertificateResponseTypeDef = TypedDict(
+    "GetCertificateAuthorityCertificateResponseTypeDef",
+    {
+        "Certificate": str,
+        "CertificateChain": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetCertificateAuthorityCsrResponseTypeDef = TypedDict(
+    "GetCertificateAuthorityCsrResponseTypeDef",
+    {
+        "Csr": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetCertificateResponseTypeDef = TypedDict(
+    "GetCertificateResponseTypeDef",
+    {
+        "Certificate": str,
+        "CertificateChain": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetPolicyResponseTypeDef = TypedDict(
+    "GetPolicyResponseTypeDef",
+    {
+        "Policy": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+IssueCertificateResponseTypeDef = TypedDict(
+    "IssueCertificateResponseTypeDef",
+    {
+        "CertificateArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsResponseTypeDef = TypedDict(
+    "ListTagsResponseTypeDef",
+    {
+        "Tags": List[TagTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+TagCertificateAuthorityRequestRequestTypeDef = TypedDict(
+    "TagCertificateAuthorityRequestRequestTypeDef",
+    {
+        "CertificateAuthorityArn": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+)
 
 UntagCertificateAuthorityRequestRequestTypeDef = TypedDict(
     "UntagCertificateAuthorityRequestRequestTypeDef",
     {
         "CertificateAuthorityArn": str,
-        "Tags": Sequence["TagTypeDef"],
+        "Tags": Sequence[TagTypeDef],
     },
 )
 
+_RequiredDescribeCertificateAuthorityAuditReportRequestAuditReportCreatedWaitTypeDef = TypedDict(
+    "_RequiredDescribeCertificateAuthorityAuditReportRequestAuditReportCreatedWaitTypeDef",
+    {
+        "CertificateAuthorityArn": str,
+        "AuditReportId": str,
+    },
+)
+_OptionalDescribeCertificateAuthorityAuditReportRequestAuditReportCreatedWaitTypeDef = TypedDict(
+    "_OptionalDescribeCertificateAuthorityAuditReportRequestAuditReportCreatedWaitTypeDef",
+    {
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeCertificateAuthorityAuditReportRequestAuditReportCreatedWaitTypeDef(
+    _RequiredDescribeCertificateAuthorityAuditReportRequestAuditReportCreatedWaitTypeDef,
+    _OptionalDescribeCertificateAuthorityAuditReportRequestAuditReportCreatedWaitTypeDef,
+):
+    pass
+
+
+_RequiredGetCertificateAuthorityCsrRequestCertificateAuthorityCSRCreatedWaitTypeDef = TypedDict(
+    "_RequiredGetCertificateAuthorityCsrRequestCertificateAuthorityCSRCreatedWaitTypeDef",
+    {
+        "CertificateAuthorityArn": str,
+    },
+)
+_OptionalGetCertificateAuthorityCsrRequestCertificateAuthorityCSRCreatedWaitTypeDef = TypedDict(
+    "_OptionalGetCertificateAuthorityCsrRequestCertificateAuthorityCSRCreatedWaitTypeDef",
+    {
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class GetCertificateAuthorityCsrRequestCertificateAuthorityCSRCreatedWaitTypeDef(
+    _RequiredGetCertificateAuthorityCsrRequestCertificateAuthorityCSRCreatedWaitTypeDef,
+    _OptionalGetCertificateAuthorityCsrRequestCertificateAuthorityCSRCreatedWaitTypeDef,
+):
+    pass
+
+
+_RequiredGetCertificateRequestCertificateIssuedWaitTypeDef = TypedDict(
+    "_RequiredGetCertificateRequestCertificateIssuedWaitTypeDef",
+    {
+        "CertificateAuthorityArn": str,
+        "CertificateArn": str,
+    },
+)
+_OptionalGetCertificateRequestCertificateIssuedWaitTypeDef = TypedDict(
+    "_OptionalGetCertificateRequestCertificateIssuedWaitTypeDef",
+    {
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class GetCertificateRequestCertificateIssuedWaitTypeDef(
+    _RequiredGetCertificateRequestCertificateIssuedWaitTypeDef,
+    _OptionalGetCertificateRequestCertificateIssuedWaitTypeDef,
+):
+    pass
+
+
+ListCertificateAuthoritiesRequestListCertificateAuthoritiesPaginateTypeDef = TypedDict(
+    "ListCertificateAuthoritiesRequestListCertificateAuthoritiesPaginateTypeDef",
+    {
+        "ResourceOwner": ResourceOwnerType,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+_RequiredListPermissionsRequestListPermissionsPaginateTypeDef = TypedDict(
+    "_RequiredListPermissionsRequestListPermissionsPaginateTypeDef",
+    {
+        "CertificateAuthorityArn": str,
+    },
+)
+_OptionalListPermissionsRequestListPermissionsPaginateTypeDef = TypedDict(
+    "_OptionalListPermissionsRequestListPermissionsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListPermissionsRequestListPermissionsPaginateTypeDef(
+    _RequiredListPermissionsRequestListPermissionsPaginateTypeDef,
+    _OptionalListPermissionsRequestListPermissionsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListTagsRequestListTagsPaginateTypeDef = TypedDict(
+    "_RequiredListTagsRequestListTagsPaginateTypeDef",
+    {
+        "CertificateAuthorityArn": str,
+    },
+)
+_OptionalListTagsRequestListTagsPaginateTypeDef = TypedDict(
+    "_OptionalListTagsRequestListTagsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListTagsRequestListTagsPaginateTypeDef(
+    _RequiredListTagsRequestListTagsPaginateTypeDef, _OptionalListTagsRequestListTagsPaginateTypeDef
+):
+    pass
+
+
+ListPermissionsResponseTypeDef = TypedDict(
+    "ListPermissionsResponseTypeDef",
+    {
+        "Permissions": List[PermissionTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RevocationConfigurationTypeDef = TypedDict(
+    "RevocationConfigurationTypeDef",
+    {
+        "CrlConfiguration": CrlConfigurationTypeDef,
+        "OcspConfiguration": OcspConfigurationTypeDef,
+    },
+    total=False,
+)
+
+PolicyQualifierInfoTypeDef = TypedDict(
+    "PolicyQualifierInfoTypeDef",
+    {
+        "PolicyQualifierId": Literal["CPS"],
+        "Qualifier": QualifierTypeDef,
+    },
+)
+
+GeneralNameTypeDef = TypedDict(
+    "GeneralNameTypeDef",
+    {
+        "OtherName": OtherNameTypeDef,
+        "Rfc822Name": str,
+        "DnsName": str,
+        "DirectoryName": ASN1SubjectTypeDef,
+        "EdiPartyName": EdiPartyNameTypeDef,
+        "UniformResourceIdentifier": str,
+        "IpAddress": str,
+        "RegisteredId": str,
+    },
+    total=False,
+)
+
 _RequiredUpdateCertificateAuthorityRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateCertificateAuthorityRequestRequestTypeDef",
     {
@@ -839,7 +849,7 @@ _RequiredUpdateCertificateAuthorityRequestRequestTypeDef = TypedDict(
 _OptionalUpdateCertificateAuthorityRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateCertificateAuthorityRequestRequestTypeDef",
     {
-        "RevocationConfiguration": "RevocationConfigurationTypeDef",
+        "RevocationConfiguration": RevocationConfigurationTypeDef,
         "Status": CertificateAuthorityStatusType,
     },
     total=False,
@@ -853,19 +863,178 @@ class UpdateCertificateAuthorityRequestRequestTypeDef(
     pass
 
 
-ValidityTypeDef = TypedDict(
-    "ValidityTypeDef",
+_RequiredPolicyInformationTypeDef = TypedDict(
+    "_RequiredPolicyInformationTypeDef",
     {
-        "Value": int,
-        "Type": ValidityPeriodTypeType,
+        "CertPolicyId": str,
     },
 )
-
-WaiterConfigTypeDef = TypedDict(
-    "WaiterConfigTypeDef",
+_OptionalPolicyInformationTypeDef = TypedDict(
+    "_OptionalPolicyInformationTypeDef",
     {
-        "Delay": int,
-        "MaxAttempts": int,
+        "PolicyQualifiers": Sequence[PolicyQualifierInfoTypeDef],
     },
     total=False,
 )
+
+
+class PolicyInformationTypeDef(
+    _RequiredPolicyInformationTypeDef, _OptionalPolicyInformationTypeDef
+):
+    pass
+
+
+AccessDescriptionTypeDef = TypedDict(
+    "AccessDescriptionTypeDef",
+    {
+        "AccessMethod": AccessMethodTypeDef,
+        "AccessLocation": GeneralNameTypeDef,
+    },
+)
+
+ExtensionsTypeDef = TypedDict(
+    "ExtensionsTypeDef",
+    {
+        "CertificatePolicies": Sequence[PolicyInformationTypeDef],
+        "ExtendedKeyUsage": Sequence[ExtendedKeyUsageTypeDef],
+        "KeyUsage": KeyUsageTypeDef,
+        "SubjectAlternativeNames": Sequence[GeneralNameTypeDef],
+        "CustomExtensions": Sequence[CustomExtensionTypeDef],
+    },
+    total=False,
+)
+
+CsrExtensionsTypeDef = TypedDict(
+    "CsrExtensionsTypeDef",
+    {
+        "KeyUsage": KeyUsageTypeDef,
+        "SubjectInformationAccess": Sequence[AccessDescriptionTypeDef],
+    },
+    total=False,
+)
+
+ApiPassthroughTypeDef = TypedDict(
+    "ApiPassthroughTypeDef",
+    {
+        "Extensions": ExtensionsTypeDef,
+        "Subject": ASN1SubjectTypeDef,
+    },
+    total=False,
+)
+
+_RequiredCertificateAuthorityConfigurationTypeDef = TypedDict(
+    "_RequiredCertificateAuthorityConfigurationTypeDef",
+    {
+        "KeyAlgorithm": KeyAlgorithmType,
+        "SigningAlgorithm": SigningAlgorithmType,
+        "Subject": ASN1SubjectTypeDef,
+    },
+)
+_OptionalCertificateAuthorityConfigurationTypeDef = TypedDict(
+    "_OptionalCertificateAuthorityConfigurationTypeDef",
+    {
+        "CsrExtensions": CsrExtensionsTypeDef,
+    },
+    total=False,
+)
+
+
+class CertificateAuthorityConfigurationTypeDef(
+    _RequiredCertificateAuthorityConfigurationTypeDef,
+    _OptionalCertificateAuthorityConfigurationTypeDef,
+):
+    pass
+
+
+_RequiredIssueCertificateRequestRequestTypeDef = TypedDict(
+    "_RequiredIssueCertificateRequestRequestTypeDef",
+    {
+        "CertificateAuthorityArn": str,
+        "Csr": Union[str, bytes, IO[Any], StreamingBody],
+        "SigningAlgorithm": SigningAlgorithmType,
+        "Validity": ValidityTypeDef,
+    },
+)
+_OptionalIssueCertificateRequestRequestTypeDef = TypedDict(
+    "_OptionalIssueCertificateRequestRequestTypeDef",
+    {
+        "ApiPassthrough": ApiPassthroughTypeDef,
+        "TemplateArn": str,
+        "ValidityNotBefore": ValidityTypeDef,
+        "IdempotencyToken": str,
+    },
+    total=False,
+)
+
+
+class IssueCertificateRequestRequestTypeDef(
+    _RequiredIssueCertificateRequestRequestTypeDef, _OptionalIssueCertificateRequestRequestTypeDef
+):
+    pass
+
+
+CertificateAuthorityTypeDef = TypedDict(
+    "CertificateAuthorityTypeDef",
+    {
+        "Arn": str,
+        "OwnerAccount": str,
+        "CreatedAt": datetime,
+        "LastStateChangeAt": datetime,
+        "Type": CertificateAuthorityTypeType,
+        "Serial": str,
+        "Status": CertificateAuthorityStatusType,
+        "NotBefore": datetime,
+        "NotAfter": datetime,
+        "FailureReason": FailureReasonType,
+        "CertificateAuthorityConfiguration": CertificateAuthorityConfigurationTypeDef,
+        "RevocationConfiguration": RevocationConfigurationTypeDef,
+        "RestorableUntil": datetime,
+        "KeyStorageSecurityStandard": KeyStorageSecurityStandardType,
+        "UsageMode": CertificateAuthorityUsageModeType,
+    },
+    total=False,
+)
+
+_RequiredCreateCertificateAuthorityRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateCertificateAuthorityRequestRequestTypeDef",
+    {
+        "CertificateAuthorityConfiguration": CertificateAuthorityConfigurationTypeDef,
+        "CertificateAuthorityType": CertificateAuthorityTypeType,
+    },
+)
+_OptionalCreateCertificateAuthorityRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateCertificateAuthorityRequestRequestTypeDef",
+    {
+        "RevocationConfiguration": RevocationConfigurationTypeDef,
+        "IdempotencyToken": str,
+        "KeyStorageSecurityStandard": KeyStorageSecurityStandardType,
+        "Tags": Sequence[TagTypeDef],
+        "UsageMode": CertificateAuthorityUsageModeType,
+    },
+    total=False,
+)
+
+
+class CreateCertificateAuthorityRequestRequestTypeDef(
+    _RequiredCreateCertificateAuthorityRequestRequestTypeDef,
+    _OptionalCreateCertificateAuthorityRequestRequestTypeDef,
+):
+    pass
+
+
+DescribeCertificateAuthorityResponseTypeDef = TypedDict(
+    "DescribeCertificateAuthorityResponseTypeDef",
+    {
+        "CertificateAuthority": CertificateAuthorityTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListCertificateAuthoritiesResponseTypeDef = TypedDict(
+    "ListCertificateAuthoritiesResponseTypeDef",
+    {
+        "CertificateAuthorities": List[CertificateAuthorityTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
